@@ -55,7 +55,7 @@ typedef struct touch_data touch_data;
      render to this view. */
   GLuint gl_framebuffer, gl_renderbuffer;
   UIDeviceOrientation orientation, new_orientation;
-  UITextView *aboutBox;
+  UIView *aboutBox;
   NSTimer *orientationTimer;
   BOOL screenLocked;
 
