@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991-2013 Jamie Zawinski <jwz@jwz.org>
+ * Copyright (c) 1991-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -187,9 +187,9 @@ static NSUserDefaultsController *staticUserDefaultsController = 0;
   // WTF, why don't we have bindings for this!!
   NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
 
-  [self setHourStyle:[defaults integerForKey:@"hourStyle"]];
-  [self setTimeStyle:[defaults integerForKey:@"timeStyle"]];
-  [self setDateStyle:[defaults integerForKey:@"dateStyle"]];
+  [self setHourStyle:(int)[defaults integerForKey:@"hourStyle"]];
+  [self setTimeStyle:(int)[defaults integerForKey:@"timeStyle"]];
+  [self setDateStyle:(int)[defaults integerForKey:@"dateStyle"]];
   [self setCycleSpeed:[defaults floatForKey:@"cycleSpeed"]];
   [self setUsesCountdownTimer:[defaults boolForKey:@"usesCountdownTimer"]];
   [self setCountdownDate:(NSDate *)[defaults objectForKey:@"countdownDate"]];
@@ -550,6 +550,11 @@ static NSUserDefaultsController *staticUserDefaultsController = 0;
      the UIDevice says we're in Portrait when we're not -- but it
      turns out that the UINavigationController knows what's up!
      So get it from there.
+     
+     NOTE!  When debugging, I thought PortraitUpsideDown was coming in as
+     Portrait, but actually what was going on was, the iPhone was upside
+     down -- but at about a 30% angle from horizontal on my desk, and that
+     was being interpreted as Portrait.  Get the angle right when debugging!
    */
   if (current == UIDeviceOrientationUnknown) {
     switch ([[[self window] rootViewController] interfaceOrientation]) {
@@ -579,6 +584,16 @@ static NSUserDefaultsController *staticUserDefaultsController = 0;
   if (current == UIDeviceOrientationUnknown)
     return;
 
+  /* iOS 7 kludge: when launching non-Portrait orientation, we get a
+     Portrait event and then the right one immediately afterward.
+     So if we're still at ratio 0, just pretend that didn't happen.
+   */
+   if (orientation == UIDeviceOrientationUnknown &&
+       current     != UIDeviceOrientationUnknown &&
+       rotation_ratio == 0) {
+     rotation_ratio = -1;
+   }
+
   if (rotation_ratio >= 0) return;	// in the midst of rotation animation
   if (orientation == current) return;	// no change
 
@@ -1496,6 +1511,7 @@ FAIL:
   tsize.height += margin * 2;
 
   frame = CGRectMake (0, 0, tsize.width, tsize.height);
+  CGRect frame2 = frame;
 
   UIInterfaceOrientation orient =
     // Why are both of these wrong when starting up rotated??
@@ -1532,34 +1548,43 @@ FAIL:
 
   if (aboutBox)
     [aboutBox removeFromSuperview];
-
-  aboutBox = [[UITextView alloc] initWithFrame:frame];
+  
+  /* The aboutBox is just a view that applies rotation.
+     Inside that is aboutText, pre-rotated, which draws the text.
+     (We used to set the transformation on the UITextView itself,
+     but that stopped working in iOS 7.)
+     Finally inside that is a CALayer that applies dropshadows to the text.
+   */
+  aboutBox = [[UIView alloc] init];
+  [aboutBox setFrame:frame];
   aboutBox.transform = CGAffineTransformMakeRotation (rot);
-  aboutBox.font = font;
-  aboutBox.textAlignment = UITextAlignmentCenter;
-  aboutBox.showsHorizontalScrollIndicator = NO;
-  aboutBox.showsVerticalScrollIndicator = NO;
-  aboutBox.scrollEnabled = NO;
-  aboutBox.textColor = [UIColor whiteColor];  // fg?
-  aboutBox.backgroundColor = [UIColor clearColor];
-  aboutBox.text = text;
-  aboutBox.editable = NO;
+  
+  UITextView *aboutText = [[UITextView alloc] initWithFrame:frame2];
+ // aboutText.transform = CGAffineTransformMakeRotation (rot);
+  aboutText.font = font;
+  aboutText.textAlignment = UITextAlignmentCenter;
+  aboutText.showsHorizontalScrollIndicator = NO;
+  aboutText.showsVerticalScrollIndicator = NO;
+  aboutText.scrollEnabled = NO;
+  aboutText.textColor = [UIColor whiteColor];  // fg?
+  aboutText.backgroundColor = [UIColor clearColor];
+  aboutText.text = text;
+  aboutText.editable = NO;
 
   // Too subtle?
-  CALayer *textLayer = (CALayer *)[aboutBox.layer.sublayers objectAtIndex:0];
+  CALayer *textLayer = (CALayer *)[aboutText.layer.sublayers objectAtIndex:0];
   textLayer.shadowColor   = [UIColor blackColor].CGColor;
   textLayer.shadowOffset  = CGSizeMake(0, 0);
   textLayer.shadowOpacity = 1;
   textLayer.shadowRadius  = 2;
-
-  CABasicAnimation *anim = 
+  CABasicAnimation *anim =
     [CABasicAnimation animationWithKeyPath:@"opacity"];
   anim.duration     = 0.3;
   anim.repeatCount  = 1;
   anim.autoreverses = NO;
   anim.fromValue    = [NSNumber numberWithFloat:0.0];
   anim.toValue      = [NSNumber numberWithFloat:1.0];
-  [aboutBox.layer addAnimation:anim forKey:@"animateOpacity"];
+  [aboutText.layer addAnimation:anim forKey:@"animateOpacity"];
 
   UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc]
                                   initWithTarget:self
@@ -1567,6 +1592,7 @@ FAIL:
   [aboutBox addGestureRecognizer: tap];
   [tap release];
 
+  [aboutBox addSubview:aboutText];
   [[self superview] addSubview:aboutBox];
 }
 
