@@ -15,6 +15,21 @@
 
 char *progname = "Dali Clock";   // digital.c wants this for error messages.
 
+
+/* Doesn't help. See comment in didRotate. */
+#if 0
+// Need to sublcass UIViewController to make PortraitUpsideDown work.
+@interface DaliClockViewController : UIViewController
+@end
+
+@implementation DaliClockViewController
+- (NSUInteger)supportedInterfaceOrientations
+{
+  return UIInterfaceOrientationMaskAll;
+}
+@end
+#endif // 0
+
 @implementation DaliPhoneAppDelegate
 
 @synthesize window;
