@@ -770,13 +770,13 @@ tick_sequence (dali_config *c)
   unsigned long msecs = now.tv_usec / 1000;
 
   if (!state->last_secs)
-    state->last_secs = secs;   /* fading in! */
+    state->last_secs = (int)secs;   /* fading in! */
   else if (secs != state->last_secs) 
     {
       /* End of the animation sequence; fill target_frames with the
          digits of the current time. */
       start_sequence (c, secs);
-      state->last_secs = secs;
+      state->last_secs = (unsigned int) secs;
     }
 
   /* Linger for about 1/10th second at the end of each cycle. */
@@ -790,8 +790,8 @@ tick_sequence (dali_config *c)
               state->orig_frames[i],
               state->current_frames[i],
               state->target_frames[i],
-              msecs);
-  state->current_msecs = msecs;
+              (unsigned int) msecs);
+  state->current_msecs = (unsigned int) msecs;
 }
 
 
